/***************************************************************************
**
**  This file is part of GeopsyCore.
**
**  GeopsyCore is free software: you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation, either version 3 of the License, or
**  (at your option) any later version.
**
**  GeopsyCore is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with Foobar.  If not, see <http://www.gnu.org/licenses/>
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2009-08-26
**  Copyright: 2009-2019
**    Marc Wathelet
**    Marc Wathelet (LGIT, Grenoble, France)
**
***************************************************************************/

#include "SyscomXmrHeader.h"

namespace GeopsyCore {

/*!
  \class SyscomXmrHeader SyscomXmrHeader.h
  \brief Brief description of class still missing

  Full description of class still missing
*/

SyscomXmrHeader::SyscomXmrHeader()
{
  TRACE;
  ASSERT(sizeof( SyscomXmrHeader)==256);
  memset(raw, 0, 256);
}

} // namespace GeopsyCore
